@@ -68,6 +68,7 @@ urpmi --auto \
       cmake \
       ccache \
       gcc-c++ \
+      yasm \
       patch \
       libdrm-devel \
       libxcb \
@@ -100,12 +101,10 @@ urpmi --auto \
       lz4-devel \
       inotify-tools-devel \
       cups-devel \
-      imagemagick \
       openal-soft-devel \
       libical-devel \
       libcap-devel \
       fontconfig-devel \
-      freetype-devel \
       patchelf \
       dpkg \
       ninja \
@@ -115,11 +114,9 @@ urpmi --auto \
       ruby \
       ruby-devel \
       sqlite3-devel \
-      ffmpeg-devel \
       boost-devel \
       gphoto2-devel \
       sane-backends \
-      jasper-devel \
       nodejs-devel \
       python3-lxml \
       perl-YAML-PP \
@@ -147,17 +144,32 @@ urpmi --auto \
       ${LIBSUFFIX}glib2.0-devel \
       ${LIBSUFFIX}usb1.0-devel \
       ${LIBSUFFIX}jpeg-devel \
+      ${LIBSUFFIX}jasper-devel \
       ${LIBSUFFIX}png-devel \
       ${LIBSUFFIX}tiff-devel \
       ${LIBSUFFIX}lqr-devel \
       ${LIBSUFFIX}fftw-devel \
       ${LIBSUFFIX}curl-devel \
-      ${LIBSUFFIX}magick-devel \
       ${LIBSUFFIX}wayland-devel \
       ${LIBSUFFIX}clang-devel \
       ${LIBSUFFIX}sm-devel \
       ${LIBSUFFIX}freeglut-devel \
-      ${LIBSUFFIX}input-devel
+      ${LIBSUFFIX}input-devel \
+      ${LIBSUFFIX}fdk-aac-devel \
+      ${LIBSUFFIX}x264-devel \
+      ${LIBSUFFIX}x265-devel \
+      ${LIBSUFFIX}xvidcore-devel \
+      ${LIBSUFFIX}vpx-devel \
+      ${LIBSUFFIX}theora-devel \
+      ${LIBSUFFIX}vorbis-devel \
+      ${LIBSUFFIX}opencore-amr-devel \
+      ${LIBSUFFIX}rtmp-devel \
+      ${LIBSUFFIX}opus-devel \
+      ${LIBSUFFIX}speex-devel \
+      ${LIBSUFFIX}mp3lame-devel \
+      ${LIBSUFFIX}freetype2-devel \
+      ${LIBSUFFIX}ass-devel
+
 
 if [[ "$DK_QTVERSION" = "5.14" ]] ; then
 
@@ -291,6 +303,12 @@ rm -fr /usr/local/lib/libssl.a    || true
 rm -fr /usr/local/lib/libcrypto.a || true
 rm -fr /usr/local/include/openssl || true
 
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_libde265      -- -j$CPU_CORES
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_libjxl        -- -j$CPU_CORES
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_libaom        -- -j$CPU_CORES
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_libavif       -- -j$CPU_CORES
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_ffmpeg        -- -j$CPU_CORES
+/opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_imagemagick   -- -j$CPU_CORES
 /opt/cmake/bin/cmake --build . --config RelWithDebInfo --target ext_opencv        -- -j$CPU_CORES
 
 #################################################################################################
