@@ -220,7 +220,7 @@ ln -s ../digikam/MANIFEST.txt           ./usr/share/showfoto/MANIFEST.txt || tru
 echo -e "---------- Copy system libraries for binary compatibility\n"
 
 # otherwise segfaults!?
-cp $(ldconfig -p | grep /$LIBSUFFIX/libsasl2.so.3      | cut -d ">" -f 2 | xargs) ./usr/lib/
+cp $(ldconfig -p | grep /${LIBSUFFIX}/libsasl2.so.3    | cut -d ">" -f 2 | xargs) ./usr/lib/
 cp $(ldconfig -p | grep /${LIBSUFFIX}/libGL.so.1       | cut -d ">" -f 2 | xargs) ./usr/lib/
 cp $(ldconfig -p | grep /${LIBSUFFIX}/libGLU.so.1      | cut -d ">" -f 2 | xargs) ./usr/lib/
 
@@ -440,7 +440,7 @@ cd usr/ ; find . -type f -exec sed -i -e 's|$APP_IMG_DIR/usr/|./././././././././
 
 # On openSUSE Qt is picking up the wrong libqxcb.so
 # (the one from the system when in fact it should use the bundled one) - is this a Qt bug?
-# Also, Krita has a hardcoded /usr which we patch away
+# Also, digiKam has a hardcoded /usr which we patch away
 cd usr/ ; find . -type f -exec sed -i -e 's|/usr|././|g' {} \; ; cd ..
 
 # We do not bundle this, so let's not search that inside the AppImage.
@@ -448,6 +448,21 @@ cd usr/ ; find . -type f -exec sed -i -e 's|/usr|././|g' {} \; ; cd ..
 sed -i -e 's|././/share/X11/|/usr/share/X11/|g' ./usr/plugins/platforminputcontexts/libcomposeplatforminputcontextplugin.so
 sed -i -e 's|././/share/X11/|/usr/share/X11/|g' ./usr/lib/libQt5XcbQpa.so.5
 
+#################################################################################################
+# Install ExifTool binary.
+
+cd $DOWNLOAD_DIR
+
+#if [ ! -f $DOWNLOAD_DIR/Image-ExifTool.tar.gz ] ; then
+    wget https://files.kde.org/digikam/exiftool/Image-ExifTool.tar.gz -O Image-ExifTool.tar.gz
+#fi
+
+tar -xvf $DOWNLOAD_DIR/Image-ExifTool.tar.gz -C $APP_IMG_DIR/usr/bin
+mv $APP_IMG_DIR/usr/bin/Image-ExifTool* $APP_IMG_DIR/usr/bin/Image-ExifTool
+
+cd $APP_IMG_DIR/usr/bin
+ln -s ./Image-ExifTool/exiftool exiftool
+
 #################################################################################################
 
 cd /
@@ -467,7 +482,7 @@ else
 
     # with official release version, disable upload to KDE server, as this break check for new version function.
     echo -e "Official release version detected, upload is disabled.\n"
-    DK_UPLOAD = 0
+    DK_UPLOAD=0
 
 fi
 
@@ -529,7 +544,7 @@ fi
 
 chmod a+x ./$APPIMGBIN
 
-ARCH=x86_64 ./$APPIMGBIN $APP_IMG_DIR/ $ORIG_WD/bundle/$APPIMAGE
+ARCH=x86_64 ./$APPIMGBIN --comp xz $APP_IMG_DIR/ $ORIG_WD/bundle/$APPIMAGE
 chmod a+rwx $ORIG_WD/bundle/$APPIMAGE
 
 #################################################################################################
