@@ -287,8 +287,9 @@ port install \
              libical \
              lensfun \
              bison \
-             py-lxml \
+             py38-lxml \
              x265 \
+             aom \
              ffmpeg \
              qt5-qtbase \
              qt5-qtdeclarative \
@@ -301,8 +302,7 @@ port install \
              qt5-qtimageformats \
              qt5-sqlite-plugin \
              qt5-mysql-plugin +mariadb10_5 \
-             wget +ssl \
-             ImageMagick
+             wget +ssl
 
 if [[ $DK_QTWEBENGINE = 1 ]] ; then
 
@@ -314,8 +314,8 @@ else
 
 fi
 
-
-#             sane-backends
+# port broken since a while. Check later
+#             sane-backends \
 
 echo -e "\n"
 
@@ -360,6 +360,10 @@ if [[ $DK_QTWEBENGINE = 0 ]] ; then
 fi
 
 cmake --build . --config RelWithDebInfo --target ext_opencv      -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_imagemagick -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_libde265    -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_libjxl      -- -j$CPU_CORES
+cmake --build . --config RelWithDebInfo --target ext_libavif     -- -j$CPU_CORES
 
 #################################################################################################
 
